summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneychecklistitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneychecklistitem.h')
-rw-r--r--kmymoney2/widgets/kmymoneychecklistitem.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/kmymoney2/widgets/kmymoneychecklistitem.h b/kmymoney2/widgets/kmymoneychecklistitem.h
index 6a22ec9..34776ce 100644
--- a/kmymoney2/widgets/kmymoneychecklistitem.h
+++ b/kmymoney2/widgets/kmymoneychecklistitem.h
@@ -21,8 +21,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qobject.h>
-#include <qlistview.h>
+#include <tqobject.h>
+#include <tqlistview.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -33,34 +33,35 @@
class KMyMoneyListViewItem;
/**
* This class implements a derived version of a QCheckListItem that
* allows the storage of an engine object id with the object and emits
* a signal upon state change.
*
* @author Thomas Baumgart
*/
-class KMyMoneyCheckListItem : public QObject, public QCheckListItem
+class KMyMoneyCheckListItem : public TQObject, public TQCheckListItem
{
friend class KMyMoneyListViewItem;
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyCheckListItem(QListView *parent, const QString& txt, const QString& key, const QString& id, Type type = QCheckListItem::CheckBox);
- KMyMoneyCheckListItem(QListView *parent, QListViewItem* after, const QString& txt, const QString& key, const QString& id, Type type = QCheckListItem::CheckBox);
- KMyMoneyCheckListItem(QListViewItem *parent, const QString& txt, const QString& key, const QString& id, Type type = QCheckListItem::CheckBox);
+ KMyMoneyCheckListItem(TQListView *tqparent, const TQString& txt, const TQString& key, const TQString& id, Type type = TQCheckListItem::CheckBox);
+ KMyMoneyCheckListItem(TQListView *tqparent, TQListViewItem* after, const TQString& txt, const TQString& key, const TQString& id, Type type = TQCheckListItem::CheckBox);
+ KMyMoneyCheckListItem(TQListViewItem *tqparent, const TQString& txt, const TQString& key, const TQString& id, Type type = TQCheckListItem::CheckBox);
~KMyMoneyCheckListItem();
- const QString& id(void) const { return m_id; };
+ const TQString& id(void) const { return m_id; };
/**
* use my own paint method
*/
- void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int alignment);
+ void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment);
/**
* use my own backgroundColor method
*/
- const QColor backgroundColor();
+ const TQColor backgroundColor();
/**
* see KListViewItem::isAlternate()
@@ -73,7 +74,7 @@ public:
* the constructor concatenated with the value returned by text(0) is returned. For @a column
* equals to 1, the @a key as passed to the constructor except the first character is returned.
*/
- QString key(int column, bool ascending) const;
+ TQString key(int column, bool ascending) const;
signals:
void stateChanged(bool);
@@ -82,8 +83,8 @@ protected:
virtual void stateChange(bool);
private:
- QString m_key;
- QString m_id;
+ TQString m_key;
+ TQString m_id;
// copied from KListViewItem()
unsigned int m_isOdd : 1;
unsigned int m_isKnown : 1;
@@ -33,34 +33,35 @@
class KMyMoneyListViewItem;
/**
- * This class implements a derived version of a QCheckListItem that
+ * This class implements a derived version of a TQCheckListItem that
* allows the storage of an engine object id with the object and emits
* a signal upon state change.